@@ -1,8 +1,7 @@
 from .auth import AuthMixin
 from .emitter import EmitterMixin
-from .parser import ParserMixin
 from .handler import HandlerMixin
+from .parser import ParserMixin
 from .throttle import ThrottleMixin
 
-
-assert AuthMixin and EmitterMixin and ParserMixin and HandlerMixin and ThrottleMixin
+# lint_ignore=W402
